@@ -1,5 +1,5 @@
 use crate::server::Asset;
-use std::net::SocketAddr;
+use std::{net::SocketAddr, path::Path};
 
 pub struct Request {
     pub addr: SocketAddr,
@@ -21,22 +21,52 @@ impl Request {
         Asset::get(&self.path)
     }
 
+    /// The HTTP content-type of the file on disk.
+    pub fn content_type(&self) -> &str {
+        if self.is_static_file() {
+            if let Some(ext) = Path::new(&self.path).extension() {
+                if let Some(ext) = ext.to_str() {
+                    return match ext {
+                        "jpg" | "jpeg" => "image/jpeg",
+                        "png" => "image/png",
+                        "gif" => "image/gif",
+                        "css" => "text/css",
+                        "js" => "text/javascript",
+                        "json" => "application/json",
+                        "html" => "text/html",
+                        _ => "text/plain",
+                    };
+                }
+            }
+        }
+        "text/html; charset=UTF-8"
+    }
+
     /// Is this request asking for a static file on disk?
     pub fn is_static_file(&self) -> bool {
         Asset::iter().find(|x| x == &self.path).is_some()
     }
 
-    /// Path without the gopher://
-    pub fn short_path(&self) -> String {
-        self.path.replace("gopher://", "")
-    }
-
     /// Parse HTTP request line to fill out this Request.
     pub fn parse(&mut self, line: &str) {
         self.path = path_from_line(line);
     }
 
-    /// Return the URL for this request.
+    /// Target URL this request wraps. Non-phroxy URL, like sdf.org.
+    pub fn target_url(&self) -> &str {
+        self.path.as_ref()
+    }
+
+    /// Target URL without the gopher://
+    pub fn short_target_url(&self) -> &str {
+        if self.target_url().starts_with("gopher://") {
+            &self.target_url()["gopher://".len()..]
+        } else {
+            self.target_url()
+        }
+    }
+
+    /// Return the phroxy URL for this request.
     pub fn url(&self) -> String {
         format!("{}/{}", self.addr, self.path)
     }
